@@ -353,6 +353,14 @@ def readSTL(filePath):
     vtkData = reader.GetOutput()
     return vtkData
     
+
+def writeSTL(filePath, vtkData):
+    writer = vtk.vtkSTLWriter()
+    writer.SetFileTypeToASCII()
+    writer.SetInputData(vtkData)
+    writer.SetFileName(filePath)
+    writer.Write()
+
     
 def writeXML3Matic(filePath, data):
     """Write to XML schema useable by Meterialise 3-matic.
@@ -387,7 +395,7 @@ def writeXML3Matic(filePath, data):
         - name: name of the entity;
         - type: type of the entity;
         it can be: 'point', 'line';
-        - 
+        - coords: Nx3 (line) or 3-elem (point) array of coordinates
 
     """
     
@@ -434,6 +442,11 @@ def readORParamsFile(fileName):
     with open(fileName) as fn:
         data = json.load(fn)
     return data
+
+
+def writedORParamsFile(fileName, params):
+    with open(fileName, 'w') as fn:
+        fn.write(json.dumps(params, indent=4))
     
     
 def writeMATFile(fileName, data):
