@@ -25,6 +25,10 @@ def performAnalysis(
         resultsDir
         ):
     
+    
+    if not os.path.exists(resultsDir):
+        os.mkdir(resultsDir)
+    
     cr = 4
     cc = 2
     
@@ -464,11 +468,76 @@ def performAnalysis(
     results['interline_angles'] = angles
 
     results['paths'] = linePaths
-
-    plt.tight_layout()
     
-    if not os.path.exists(resultsDir):
-        os.mkdir(resultsDir)
+    
+    defScenes = params['defScenes']
+    
+    scenesList = params['useScenes']['selected']
+
+    for sceneName in scenesList:
+
+        defScene = [l for l in defScenes if l['name'] == sceneName][0]
+        geomNames = defScene['geomItems']
+        pointNames = defScene['pointItems']
+        refName = defScene['ref']
+        frames = defScene['frames']
+        exporter = defScene['exporter']
+        
+        RT = RTs[refName]
+        RTi = kine.inv2(RT)
+        RTRef = RTi
+        
+        if geomNames == 'all_selected':
+            meshNames = list(meshes.keys())
+        RTsRef = {m: kine.dot3(RTRef, RTs[m]) for m in meshNames}
+                
+        if pointNames == 'all_selected':
+            points = results['landmarks']
+        pointsInRef = kine.changeMarkersReferenceFrame(points, RTRef)
+        
+        if frames == 'all':
+            frames_ = list(range(N))
+        elif frames == 'first_and_last':
+            frames_ = [0, N-1]
+        else:
+            frames_ = frames[:]
+         
+        for i in range(N):
+            
+            if i in frames_:
+                
+                folderName = '%s_fr_%05d' % (sceneName, i)
+                folderPath = os.path.join(resultsDir, folderName)
+                
+                if not os.path.exists(folderPath):
+                    os.mkdir(folderPath)
+                
+                exportSTLs = False
+                
+                if exporter == 'XML3Matic':
+                    
+                    pointCloud = []
+                    for m in pointsInRef:
+                        item = {}
+                        item['name'] = str(m)
+                        item['type'] = 'point'
+                        item['coords'] = pointsInRef[m][i,:]
+                        pointCloud.append(item)
+    
+                    filePathXML = os.path.join(folderPath, 'mimics.xml')
+                    fio.writeXML3Matic(filePathXML, pointCloud)
+                    
+                    exportSTLs = True
+                    
+                if exportSTLs:
+                    
+                    for m in meshNames:
+                        meshInRef = vtkh.reposeVTKData(meshes[m], RTsRef[m][i,...])
+                        filePathSTL = os.path.join(folderPath, '%s.stl' % m)
+                        fio.writeSTL(filePathSTL, meshInRef)
+
+    
+    plt.tight_layout()
     
     manager = plt.get_current_fig_manager()
     manager.window.showMaximized()
